@@ -28,23 +28,10 @@ enum {
     N_CLONE_STATES,
 };
 
-enum {
-    CLONE_OK,
-    CLONE_ERROR_CHECK_SERVER,
-    CLONE_ERROR_INDEX,
-    CLONE_ERROR_FETCH,
-    CLONE_ERROR_PASSWD,
-    CLONE_ERROR_CHECKOUT,
-    CLONE_ERROR_MERGE,
-    CLONE_ERROR_INTERNAL,
-    N_CLONE_ERRORS,
-};
-
 struct _CloneTask {
     SeafCloneManager    *manager;
     int                  state;
     int                  error;
-    char                *err_detail;
     char                 repo_id[37];
     int                  repo_version;
     char                 peer_id[41];
@@ -77,9 +64,6 @@ struct _CloneTask {
 const char *
 clone_task_state_to_str (int state);
 
-const char *
-clone_task_error_to_str (int error);
-
 struct _SeafCloneManager {
     struct _SeafileSession  *seaf;
     sqlite3                 *db;
@@ -105,7 +89,6 @@ char *
 seaf_clone_manager_add_task (SeafCloneManager *mgr, 
                              const char *repo_id,
                              int repo_version,
-                             const char *peer_id,
                              const char *repo_name,
                              const char *token,
                              const char *passwd,
@@ -113,8 +96,6 @@ seaf_clone_manager_add_task (SeafCloneManager *mgr,
                              int enc_version,
                              const char *random_key,
                              const char *worktree,
-                             const char *peer_addr,
-                             const char *peer_port,
                              const char *email,
                              const char *more_info,
                              GError **error);
@@ -128,7 +109,6 @@ char *
 seaf_clone_manager_add_download_task (SeafCloneManager *mgr, 
                                       const char *repo_id,
                                       int repo_version,
-                                      const char *peer_id,
                                       const char *repo_name,
                                       const char *token,
                                       const char *passwd,
@@ -136,8 +116,6 @@ seaf_clone_manager_add_download_task (SeafCloneManager *mgr,
                                       int enc_version,
                                       const char *random_key,
                                       const char *wt_parent,
-                                      const char *peer_addr,
-                                      const char *peer_port,
                                       const char *email,
                                       const char *more_info,
                                       GError **error);
@@ -146,10 +124,6 @@ int
 seaf_clone_manager_cancel_task (SeafCloneManager *mgr,
                                 const char *repo_id);
 
-int
-seaf_clone_manager_remove_task (SeafCloneManager *mgr,
-                                const char *repo_id);
-
 CloneTask *
 seaf_clone_manager_get_task (SeafCloneManager *mgr,
                              const char *repo_id);
